

STATE_SIZE = 512  
WORD_SIZE = 128   
NUM_WORDS = 4
BLOCK_SIZE = 64   

ROUNDS_256 = 20
ROUNDS_384 = 22
ROUNDS_512 = 24

PRIME_ROTATIONS = [17, 31, 61, 127]

GF128_POLY = 0b10000111

LWE_MODULUS = 257
LWE_ERROR_SIGMA = 3.2
SBOX_COUNT = 8
SBOX_SIZE = 256

SBOX_REGEN_BYTES = 1024 * 1024  


NTRU_N = 512
NTRU_Q = 2**128


NONCE_SIZE = 16  